function plot(oData,varargin)

%PLOT Linear plot. 
%   PLOT(oData,{'X1','Y1',legend},{'X2','Y2',legend},....,options)
% 
%   It plots the X1 against Y1 on Y and X axes respectively.Similary X2 
%   against Y2 on the same plot.
%   Here X1,X2,Y1,Y2 are expressions in terms of state variables of the system.
%   If plot against time is required put't' instead of the corresponding expression.
%   Depending on the values of fields in the odject it plots stochastic or
%   deterministic simualtion results.
%   Legend is optional.
%   Each plot has its own cell. If no cells are given as input, the output is plotted against time(time on X axis).
% 
%   Style is optional and can be set from options structure.
%   It works as follows:
%   Nothing -> default plots (lines) 
%   'dots' -> plot of dots ('.'), no line; everything else default 
%   'boldlines' -> linewidth = 2 ; legend in font size 16, font weight demi.Ticks in font size 14, font weight 14 .
%   'bolddots' -> markersize = 15, no line, marker '.' ; everything else as 'boldlines' 
%   Same with 'dash' and 'bolddash' : line as '--' 
% 
%   eg. plotmodel(a1,T,X,{'X1','X2','leg1'},{'X1','X1+X2','leg2'},a)
%   where a is a structure of type option. eg. a=optionset('Style','dash');


n=length(varargin);
% default case,only one argument ie. the object
if(n==0)
    if(ndims(oData.X)==3)
        eval(sprintf('plotmean(oData);'))
    elseif(ndims(oData.X)==2)
        eval(sprintf('plotmodel(oData);'))
    else
        error('Wrong dimension of X,should either be 2 or 3')
    end
else
    temp=varargin{n};
% check if style argument is given
if (isstruct(temp))
    %  --------------------case with style argument-----------
    a=temp;
    n=n-1; 
else
    a='none';
end
% reproducing the input string, with cells
str='';
for i=1:n
    if (length(varargin{i})==3)
        cell=varargin{i};
        temp=strcat('{','''',cell{1},'''',',','''',cell{2},'''',',','''',cell{3},'''','}');
    elseif (length(varargin{i})==2)
        cell=varargin{i};
        temp=strcat('{','''',cell{1},'''',',','''',cell{2},'''','}');
    end
    str = strcat(str,',',temp);

end

% case with no style argument
if(strcmp(a,'none'))
    if(ndims(oData.X)==3)
        eval(sprintf('plotmean(oData%s);',str));
    elseif(ndims(oData.X)==2)
        eval(sprintf('plotmodel(oData%s);',str));
    else
        error('Wrong dimension of X,should either be 2 or 3')
    end
else
    if(ndims(oData.X)==3)
        eval(sprintf('plotmean(oData%s,a);',str));
    elseif(ndims(oData.X)==2)
        eval(sprintf('plotmodel(oData%s,a);',str));
    else
        error('Wrong dimension of X,should either be 2 or 3')
    end
end
end
 
