function [display, handles] = analyzevolumeMC(newgoods, sets)

% analyzeMCvolume
%
% display = analyzeMCvolume(newgoods, sets)
%
%   Plot the distribution of the volumeMC_alongPCA results
%   allsets optional
%
%   output = std deviation and eigendirection of the goods sets
%            handles to the plot
%
%
% Version 1, october 2008
% Marc Hafner, EPFL-IC-LANOS, Switzerland
% help and comments to marc.hafner@epfl.ch
%

variance = var(newgoods);
lk = sum(variance>1e-20);

ksign = sign(mean(newgoods(:,1:lk)));
setstoplot = length(newgoods);

if ~exist('sets','var')
    for i=1:setstoplot
        sets(1,:) = max(newgoods);
        sets(2,:) = min(newgoods);
    end
end
        

maxk = max([newgoods(:,1:lk);sets(:,1:lk)]).*(1+.1*ksign);
mink = min([newgoods(:,1:lk);sets(:,1:lk)]).*(1-.1*ksign);    


    h = plotks(sets(:,1:lk),'.','color',[.5 .6 .5],'markersize',14);
    hold on
    plotks(newgoods(:,1:lk),'.','color',[0 0 .8],'markersize',14);
    hold off
    standard_graph(h);
    
    legend(h.sub{end}.f,'tested parameter','viable parameter');

    for i=1:length(h.sub)
        
        
        axes(h.sub{i}.f)
        
        xlim([mink(2*i-1) maxk(2*i-1)])
        2*i-1
        minxtick = floor(log10(ksign(2*i-1)*mink(2*i-1)));
        maxxtick = ceil(log10(ksign(2*i-1)*maxk(2*i-1)));
        xticks = [minxtick (minxtick+ksign(2*i-1)):ceil((maxxtick-minxtick)/4):(maxxtick-ksign(2*i-1)) maxxtick];
        if 1% ksign(2*i-1)>0   
            ksign(2*i-1)*10.^xticks
            set(h.sub{i}.f,'XTick',ksign(2*i-1)*10.^xticks)
        else
            ksign(2*i-1)*10.^xticks(end:-1:1)
            set(h.sub{i}.f,'XTick',ksign(2*i-1)*10.^xticks(end:-1:1))
        end
        
        if i==length(h.sub) && mod(lk,2)==1
            jj = 2*i-2;
        else
            jj = 2*i;
        end
        minytick = floor(log10(ksign(jj)*mink(jj)));
        maxytick = ceil(log10(ksign(jj)*maxk(jj)));
        yticks = [minytick (minytick+ksign(jj)):ceil((maxytick-minytick)/4):maxytick-(ksign(jj)) maxytick];
%         if 1% ksign(jj)>0   
            ksign(jj)*10.^yticks;
            set(h.sub{i}.f,'YTick',ksign(jj)*10.^yticks)
%         else
%             ksign(jj)*10.^yticks(end:-1:1)
%             set(h.sub{i}.f,'YTick',ksign(jj)*10.^yticks(end:-1:1))
%         end
        
        set(h.sub{i}.f,'XMinorTick','on', 'YMinorTick','on');

    end
    
    legend(h.sub{end}.f,'tested parameter','viable parameter','original parameter');

    handles = h;



    logks = log10(newgoods(:,1:lk).*(ones(size(newgoods(:,1:lk),1),1)*ksign));
    [axis, coord, latent] = princomp(logks);
    display = [sqrt(latent) ones(length(ksign),1)*i axis];
