function handle = plotmodel(oData,varargin)
%PLOTMODEL  Linear plot. 
%   PLOTMODEL(oData, {'X1','Y1',legend}, {'X2','Y2',legend}, ..., options)
% 
%   It plots the X1 against Y1 on Y and X axes respectively.Similary X2 
%   against Y2 on the same plot.
%   Here X1,X2,Y1,Y2 are expressions in terms of state variables of the system.
%   If plot against time is required put't' instead of the corresponding expression.
%   
%   Legend is optional.
%   Each plot has its own cell. If no cells are given as input, the output is plotted against time(time on X axis).
% 
%   options are the usual options for plot function.
%
% See also PLOT, DATA, EXTRACTX.
%
% Version 1, October 2008
% Marc Hafner, EPFL-IC-LANOS, Switzerland
% help and comments to marc.hafner@epfl.ch
%

if isa(oData,'data')==0
    error('input is not a class data')
end

    
n=length(varargin);



    
j=0;
k=0;
options={};
toplot={};
for i=1:n
    if iscell(varargin{i})
        j=1+j;
        toplot{j} = varargin{i};
    else
        k=1+k;
        options{k} = varargin{i};
    end
end

if isempty(toplot)
    handle = plot(oData.T,extractX(oData, oData.Output),options{1:end});
    legend([oData.ModelName ' Output']);
    return;
end

logichold = ishold;

colors='kbrgcmy';
for i=1:length(toplot)
    
    if strcmpi(toplot{i}(2),'output')
        toplot{i}{2} = oData.Output;
    end
    if strcmpi(toplot{i}{1},'t')
        handle = plot(oData.T,extractX(oData, toplot{i}{2}), options{1:end}, 'color', colors(mod(i-1,7)+1));
    else
        handle = plot(extractX(oData, toplot{i}{1}),extractX(oData, toplot{i}{2}), options{1:end}, 'color', colors(mod(i-1,7)+1));
    end
    
    if length(toplot{i})==3
        leg{i} = toplot{i}{3};
    end
    hold on
end

if exist('leg','var')
    legend(leg{1:end});
end
      
if logichold==0
    hold off
end
    
    
        



    
    